======================
Boilerplate for Django
======================

Write Django as usual, and let ``django-boilerplate`` help you with the usually painfull stuff.


.. image:: https://img.shields.io/travis/cubope/django-boilerplate/master.svg
    :target: https://travis-ci.org/cubope/django-boilerplate

.. image:: https://img.shields.io/coveralls/cubope/django-boilerplate/master.svg
  :target: https://coveralls.io/r/cubope/django-boilerplate?branch=master


Requirements
------------

- Python 2.7, 3.2, 3.3, 3.4, or 3.5
- Django >= 1.8

*The latest version supporting Python 2.6 and Django < 1.8 is the 6.x.x branch.*


Installation
------------
1. Install using pip:

   ``pip install django-boilerplate``

   Alternatively, you can install download or clone this repo and call ``pip install -e .``.

2. Add to INSTALLED_APPS in your ``settings.py``:

   ``'boilerplate',``

3. In your templates, load the ``boilerplate`` library and use the ``boilerplate`` tags:

This app will soon require Django 1.8+, python 2.7+. Thanks for understanding.


Bugs and suggestions
--------------------

If you have found a bug or if you have a request for additional functionality, please use the issue tracker on GitHub.

https://github.com/cubope/django-boilerplate/issues


License
-------

You can use this under Apache 2.0. See `LICENSE
<LICENSE>`_ file for details.


Author
------

Developed and maintained by `Cubo <http://cubo.pe/>`_.

Original author & Development lead: `Irving Kcam <https://github.com/ikcam>`_.

Thanks to everybody that has contributed pull requests, ideas, issues, comments and kind words.

Please see AUTHORS.rst for a list of contributors.